@@ -1,15 +1,13 @@
 from typing import Any, Dict, Optional, Type
 
 from graphql import (
+    GraphQLInputField,
     GraphQLInputFieldMap,
     GraphQLInputType,
-    GraphQLNonNull, GraphQLInputField
+    GraphQLNonNull,
 )
 
-from .base import (
-    BuilderBase,
-    GraphQLInputObjectTypeMap
-)
+from .base import BuilderBase, GraphQLInputObjectTypeMap
 from .utils import is_required
 
 GraphQLInputTypeMap = Dict[str, GraphQLInputType]
@@ -23,11 +21,11 @@ class MutationBuilder(BuilderBase):
         result: GraphQLInputFieldMap = {}
 
         for build_type in self.build_type(source):
-            if build_type.metadata.get('readonly') is True:
+            if build_type.metadata.get("readonly") is True:
                 continue
 
             field_name = self.field_name(build_type.field)
-            description = build_type.metadata.get('description', '')
+            description = build_type.metadata.get("description", "")
             mapped_type = self.map_input(build_type.source)
 
             if is_required(build_type.field):
