@@ -1,13 +1,13 @@
-from typing import Sequence, Any, Union
+from typing import Any, Sequence, Union
 
 from graphql import (
     ExecutionContext,
-    GraphQLField,
     FieldNode,
+    GraphQLError,
+    GraphQLField,
     GraphQLFieldResolver,
     GraphQLResolveInfo,
-    GraphQLError,
-    is_introspection_type
+    is_introspection_type,
 )
 from graphql.execution.values import get_argument_values
 
@@ -21,12 +21,14 @@ class TGQLExecutionContext(ExecutionContext):
         field_nodes: Sequence[FieldNode],
         resolve_fn: GraphQLFieldResolver,
         source: Any,
-        info: GraphQLResolveInfo
+        info: GraphQLResolveInfo,
     ) -> Union[Exception, Any]:
         try:
             is_introspection = is_introspection_type(info.parent_type)
-            camelcase = getattr(info.schema, 'camelcase', False)
-            arguments = get_argument_values(field_def, field_nodes[0], self.variable_values)
+            camelcase = getattr(info.schema, "camelcase", False)
+            arguments = get_argument_values(
+                field_def, field_nodes[0], self.variable_values
+            )
             if camelcase and not is_introspection:
                 arguments = to_snake(arguments=arguments)
             result = resolve_fn(source, info, **arguments)
